@@ -1,19 +1,19 @@
 create table one (
-	firstname string not null,
-	lastname string not null,
+	firstname varchar2(255) not null,
+	lastname varchar2(255) not null,
 	age integer not null
 );
 
 create table two (
 	two_id integer not null primary key,
-	firstname string not null,
-	lastname string not null,
+	firstname varchar2(255) not null,
+	lastname varchar2(255) not null,
 	age integer not null
 );
 
 create table three (
-	firstname string not null,
-	lastname string not null,
+	firstname varchar2(255) not null,
+	lastname varchar2(255) not null,
 	age integer not null,
 	primary key ( firstname, lastname )
 );
@@ -23,3 +23,8 @@ create view four as select * from one;
 create view five as select * from two;
 
 create view six as select * from three;
+
+create table seven (
+	name varchar2(255) not null primary key,
+	age integer not null
+);
